==> haskell-tasty-sugar-2.2.2.1-72-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-DmVgftAZum7LtOQWIo4kRT-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-DmVgftAZum7LtOQWIo4kRT-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  3e204052f4046e2cd6d48276745639f8
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-DmVgftAZum7LtOQWIo4kRT-tasty-sugar-internal

depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-6V4CNJFHbtkIqz2ftt7SXD filepath-1.4.300.1
    kvitable-1.1.1.0-9hNdcE2myDDAv3wKM6uX4J
    logict-0.8.2.0-IuAOa7GKoiODJvNxdRS5Nd
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-9ui5sY9vSM4DZoTXPVxdqe
key:                  tasty-sugar-2.2.2.1-9ui5sY9vSM4DZoTXPVxdqe
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  899dcd1e9c43ebe7b6079065e36f4ce6
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-9ui5sY9vSM4DZoTXPVxdqe
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-6V4CNJFHbtkIqz2ftt7SXD filepath-1.4.300.1
    logict-0.8.2.0-IuAOa7GKoiODJvNxdRS5Nd
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    tasty-sugar-2.2.2.1-DmVgftAZum7LtOQWIo4kRT-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.2.2.1-74-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-2grfzJG0IshKyCoGSyEoBz-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-2grfzJG0IshKyCoGSyEoBz-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  b2f7d15aed1454bc7a30c1659eda7d6a
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-2grfzJG0IshKyCoGSyEoBz-tasty-sugar-internal

depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p filepath-1.4.300.1
    kvitable-1.1.1.0-CvbNvV7AqzCHyicAPIUAox
    logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-5B45hiBChOPAwsRJ31SMts
key:                  tasty-sugar-2.2.2.1-5B45hiBChOPAwsRJ31SMts
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  c28ae6ba530b68d967e70731b3ca1b0c
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-5B45hiBChOPAwsRJ31SMts
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p filepath-1.4.300.1
    logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    tasty-sugar-2.2.2.1-2grfzJG0IshKyCoGSyEoBz-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
